@@ -410,8 +410,8 @@ class webull :
         if stock and isinstance(stock, str):
             response = requests.get(self._urls.stock_id(stock, self._region_code), headers=headers, timeout=self.timeout)
             result = response.json()
-            if result.get('data') :
-                for item in result['data'] : # implies multiple tickers, but only assigns last one?
+            if result.get('list') :
+                for item in result['list'] : # implies multiple tickers, but only assigns last one?
                     if 'symbol' in item and item['symbol'] == stock :
                         ticker_id = item['tickerId']
                         break
